@@ -7,11 +7,12 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/go-task/task/v3/args"
-	"github.com/go-task/task/v3/internal/omap"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
 
 func TestArgs(t *testing.T) {
+	t.Parallel()
+
 	tests := []struct {
 		Args            []string
 		ExpectedCalls   []*ast.Call
@@ -32,30 +33,40 @@ func TestArgs(t *testing.T) {
 				{Task: "task-b"},
 				{Task: "task-c"},
 			},
-			ExpectedGlobals: &ast.Vars{
-				OrderedMap: omap.FromMapWithOrder(
-					map[string]ast.Var{
-						"FOO": {Value: "bar"},
-						"BAR": {Value: "baz"},
-						"BAZ": {Value: "foo"},
+			ExpectedGlobals: ast.NewVars(
+				&ast.VarElement{
+					Key: "FOO",
+					Value: ast.Var{
+						Value: "bar",
 					},
-					[]string{"FOO", "BAR", "BAZ"},
-				),
-			},
+				},
+				&ast.VarElement{
+					Key: "BAR",
+					Value: ast.Var{
+						Value: "baz",
+					},
+				},
+				&ast.VarElement{
+					Key: "BAZ",
+					Value: ast.Var{
+						Value: "foo",
+					},
+				},
+			),
 		},
 		{
 			Args: []string{"task-a", "CONTENT=with some spaces"},
 			ExpectedCalls: []*ast.Call{
 				{Task: "task-a"},
 			},
-			ExpectedGlobals: &ast.Vars{
-				OrderedMap: omap.FromMapWithOrder(
-					map[string]ast.Var{
-						"CONTENT": {Value: "with some spaces"},
+			ExpectedGlobals: ast.NewVars(
+				&ast.VarElement{
+					Key: "CONTENT",
+					Value: ast.Var{
+						Value: "with some spaces",
 					},
-					[]string{"CONTENT"},
-				),
-			},
+				},
+			),
 		},
 		{
 			Args: []string{"FOO=bar", "task-a", "task-b"},
@@ -63,14 +74,14 @@ func TestArgs(t *testing.T) {
 				{Task: "task-a"},
 				{Task: "task-b"},
 			},
-			ExpectedGlobals: &ast.Vars{
-				OrderedMap: omap.FromMapWithOrder(
-					map[string]ast.Var{
-						"FOO": {Value: "bar"},
+			ExpectedGlobals: ast.NewVars(
+				&ast.VarElement{
+					Key: "FOO",
+					Value: ast.Var{
+						Value: "bar",
 					},
-					[]string{"FOO"},
-				),
-			},
+				},
+			),
 		},
 		{
 			Args:          nil,
@@ -83,25 +94,32 @@ func TestArgs(t *testing.T) {
 		{
 			Args:          []string{"FOO=bar", "BAR=baz"},
 			ExpectedCalls: []*ast.Call{},
-			ExpectedGlobals: &ast.Vars{
-				OrderedMap: omap.FromMapWithOrder(
-					map[string]ast.Var{
-						"FOO": {Value: "bar"},
-						"BAR": {Value: "baz"},
+			ExpectedGlobals: ast.NewVars(
+				&ast.VarElement{
+					Key: "FOO",
+					Value: ast.Var{
+						Value: "bar",
 					},
-					[]string{"FOO", "BAR"},
-				),
-			},
+				},
+				&ast.VarElement{
+					Key: "BAR",
+					Value: ast.Var{
+						Value: "baz",
+					},
+				},
+			),
 		},
 	}
 
 	for i, test := range tests {
 		t.Run(fmt.Sprintf("TestArgs%d", i+1), func(t *testing.T) {
+			t.Parallel()
+
 			calls, globals := args.Parse(test.Args...)
 			assert.Equal(t, test.ExpectedCalls, calls)
 			if test.ExpectedGlobals.Len() > 0 || globals.Len() > 0 {
-				assert.Equal(t, test.ExpectedGlobals.Keys(), globals.Keys())
-				assert.Equal(t, test.ExpectedGlobals.Values(), globals.Values())
+				assert.Equal(t, test.ExpectedGlobals, globals)
+				assert.Equal(t, test.ExpectedGlobals, globals)
 			}
 		})
 	}
