@@ -70,12 +70,13 @@ type Executor struct {
 	Stdout io.Writer
 	Stderr io.Writer
 
-	Logger         *logger.Logger
-	Compiler       *compiler.Compiler
-	Output         output.Output
-	OutputStyle    ast.Output
-	TaskSorter     sort.TaskSorter
-	UserWorkingDir string
+	Logger             *logger.Logger
+	Compiler           *compiler.Compiler
+	Output             output.Output
+	OutputStyle        ast.Output
+	TaskSorter         sort.TaskSorter
+	UserWorkingDir     string
+	EnableVersionCheck bool
 
 	fuzzyModel *fuzzy.Model
 
@@ -176,6 +177,10 @@ func (e *Executor) RunTask(ctx context.Context, call *ast.Call) error {
 		return nil
 	}
 
+	if err := e.areTaskRequiredVarsSet(t); err != nil {
+		return err
+	}
+
 	t, err = e.CompiledTask(call)
 	if err != nil {
 		return err
@@ -202,10 +207,6 @@ func (e *Executor) RunTask(ctx context.Context, call *ast.Call) error {
 				return err
 			}
 
-			if err := e.areTaskRequiredVarsSet(t, call); err != nil {
-				return err
-			}
-
 			preCondMet, err := e.areTaskPreconditionsMet(ctx, t)
 			if err != nil {
 				return err
@@ -383,7 +384,7 @@ func (e *Executor) runCommand(ctx context.Context, t *ast.Task, call *ast.Call,
 		if err != nil {
 			return fmt.Errorf("task: failed to get variables: %w", err)
 		}
-		stdOut, stdErr, close := outputWrapper.WrapWriter(e.Stdout, e.Stderr, t.Prefix, outputTemplater)
+		stdOut, stdErr, closer := outputWrapper.WrapWriter(e.Stdout, e.Stderr, t.Prefix, outputTemplater)
 
 		err = execext.RunCommand(ctx, &execext.RunCommandOptions{
 			Command:   cmd.Cmd,
@@ -395,7 +396,7 @@ func (e *Executor) runCommand(ctx context.Context, t *ast.Task, call *ast.Call,
 			Stdout:    stdOut,
 			Stderr:    stdErr,
 		})
-		if closeErr := close(err); closeErr != nil {
+		if closeErr := closer(err); closeErr != nil {
 			e.Logger.Errf(logger.Red, "task: unable to close writer: %v\n", closeErr)
 		}
 		if _, isExitError := interp.IsExitStatus(err); isExitError && cmd.IgnoreError {
@@ -451,7 +452,7 @@ func (e *Executor) GetTask(call *ast.Call) (*ast.Task, error) {
 	case 0: // Carry on
 	case 1:
 		if call.Vars == nil {
-			call.Vars = &ast.Vars{}
+			call.Vars = ast.NewVars()
 		}
 		call.Vars.Set("MATCH", ast.Var{Value: matchingTasks[0].Wildcards})
 		return matchingTasks[0].Task, nil
