@@ -8,10 +8,10 @@ import (
 	"github.com/joho/godotenv"
 
 	"github.com/go-task/task/v3/errors"
+	"github.com/go-task/task/v3/internal/env"
 	"github.com/go-task/task/v3/internal/execext"
 	"github.com/go-task/task/v3/internal/filepathext"
 	"github.com/go-task/task/v3/internal/fingerprint"
-	"github.com/go-task/task/v3/internal/omap"
 	"github.com/go-task/task/v3/internal/templater"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
@@ -57,7 +57,7 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 		Dir:                  templater.Replace(origTask.Dir, cache),
 		Set:                  origTask.Set,
 		Shopt:                origTask.Shopt,
-		Vars:                 nil,
+		Vars:                 vars,
 		Env:                  nil,
 		Dotenv:               templater.Replace(origTask.Dotenv, cache),
 		Silent:               origTask.Silent,
@@ -86,7 +86,7 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 		new.Prefix = new.Task
 	}
 
-	dotenvEnvs := &ast.Vars{}
+	dotenvEnvs := ast.NewVars()
 	if len(new.Dotenv) > 0 {
 		for _, dotEnvPath := range new.Dotenv {
 			dotEnvPath = filepathext.SmartJoin(new.Dir, dotEnvPath)
@@ -98,14 +98,14 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 				return nil, err
 			}
 			for key, value := range envs {
-				if ok := dotenvEnvs.Exists(key); !ok {
+				if _, ok := dotenvEnvs.Get(key); !ok {
 					dotenvEnvs.Set(key, ast.Var{Value: value})
 				}
 			}
 		}
 	}
 
-	new.Env = &ast.Vars{}
+	new.Env = ast.NewVars()
 	new.Env.Merge(templater.ReplaceVars(e.Taskfile.Env, cache), nil)
 	new.Env.Merge(templater.ReplaceVars(dotenvEnvs, cache), nil)
 	new.Env.Merge(templater.ReplaceVars(origTask.Env, cache), nil)
@@ -116,7 +116,7 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 				new.Env.Set(k, ast.Var{Value: v.Value})
 				return nil
 			}
-			static, err := e.Compiler.HandleDynamicVar(v, new.Dir)
+			static, err := e.Compiler.HandleDynamicVar(v, new.Dir, env.GetFromVars(new.Env))
 			if err != nil {
 				return err
 			}
@@ -128,6 +128,23 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 		}
 	}
 
+	if len(origTask.Sources) > 0 {
+		timestampChecker := fingerprint.NewTimestampChecker(e.TempDir.Fingerprint, e.Dry)
+		checksumChecker := fingerprint.NewChecksumChecker(e.TempDir.Fingerprint, e.Dry)
+
+		for _, checker := range []fingerprint.SourcesCheckable{timestampChecker, checksumChecker} {
+			value, err := checker.Value(&new)
+			if err != nil {
+				return nil, err
+			}
+			vars.Set(strings.ToUpper(checker.Kind()), ast.Var{Live: value})
+		}
+
+		// Adding new variables, requires us to refresh the templaters
+		// cache of the the values manually
+		cache.ResetCache()
+	}
+
 	if len(origTask.Cmds) > 0 {
 		new.Cmds = make([]*ast.Cmd, 0, len(origTask.Cmds))
 		for _, cmd := range origTask.Cmds {
@@ -229,21 +246,6 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 	}
 
 	if len(origTask.Status) > 0 {
-		timestampChecker := fingerprint.NewTimestampChecker(e.TempDir.Fingerprint, e.Dry)
-		checksumChecker := fingerprint.NewChecksumChecker(e.TempDir.Fingerprint, e.Dry)
-
-		for _, checker := range []fingerprint.SourcesCheckable{timestampChecker, checksumChecker} {
-			value, err := checker.Value(&new)
-			if err != nil {
-				return nil, err
-			}
-			vars.Set(strings.ToUpper(checker.Kind()), ast.Var{Live: value})
-		}
-
-		// Adding new variables, requires us to refresh the templaters
-		// cache of the the values manually
-		cache.ResetCache()
-
 		new.Status = templater.Replace(origTask.Status, cache)
 	}
 
@@ -297,11 +299,11 @@ func itemsFromFor(
 	// Get the list from a variable and split it up
 	if f.Var != "" {
 		if vars != nil {
-			v := vars.Get(f.Var)
+			v, ok := vars.Get(f.Var)
 			// If the variable is dynamic, then it hasn't been resolved yet
 			// and we can't use it as a list. This happens when fast compiling a task
 			// for use in --list or --list-all etc.
-			if v.Value != nil && v.Sh == nil {
+			if ok && v.Sh == nil {
 				switch value := v.Value.(type) {
 				case string:
 					if f.Split != "" {
@@ -333,7 +335,7 @@ func itemsFromFor(
 }
 
 // product generates the cartesian product of the input map of slices.
-func product(inputMap omap.OrderedMap[string, []any]) []map[string]any {
+func product(inputMap *ast.Matrix) []map[string]any {
 	if inputMap.Len() == 0 {
 		return nil
 	}
